@@ -14,7 +14,7 @@ main (int argc, char *argv[])
     char *line = NULL;
     size_t len = 0;
     ssize_t read = 0;
-    int r;
+    eav_result_t r;
     FILE *fh;
     char *file = NULL;
     int expect_pass = -1;
@@ -50,7 +50,7 @@ main (int argc, char *argv[])
         len = strlen (line);
         r = is_822_email (line, len, true);
 
-        if (r >= 0) {
+        if (r.rc >= 0) {
             printf ("PASS: %s\n", sanitize(line, len));
             passed++;
         }
